<template>
  <div class="notice">
    <el-dialog
        v-model="dialogVisible"
        :title="title"
        width="500px"
        :before-close="handleClose"
        :close-on-press-escape="false"
        :close-on-click-modal="false"
    >
      <el-form :model="state.form" size="default" ref="busRef" :rules="state.formRules" label-width="150px" >
        <el-form-item label="企业信用代码:" prop="creditCode" v-if="title!=='分配课时'">
          <el-input v-model.trim="state.form.creditCode" placeholder="请输入企业信用代码"></el-input>
        </el-form-item>
        <el-form-item label="企业名称:" prop="name" v-if="title!=='分配课时'">
          <el-input v-model.trim="state.form.name" placeholder="请输入企业名称"></el-input>
        </el-form-item>
        <el-form-item label="负责人:" prop="major" v-if="title!=='分配课时'">
          <el-input v-model.trim="state.form.major" placeholder="请输入负责人"></el-input>
        </el-form-item>
        <el-form-item label="联系电话:" prop="phone" v-if="title!=='分配课时'">
          <el-input v-model.trim="state.form.phone" placeholder="请输入联系电话"></el-input>
        </el-form-item>
        <el-form-item label="当前剩余课时:" prop="remainPeriod" v-if="title!=='分配课时' && title==='编辑'">
          <el-input
              placeholder="请输入剩余课时"
              v-model.trim="state.form.remainPeriod"
              @input="state.form.remainPeriod= state.form.remainPeriod.replace(/[^0-9]/g,'')">
            <template #append >分钟</template>
          </el-input>
        </el-form-item>
<!--        <el-form-item label="累计已用课时(秒):" prop="spendPeriod" v-if="title!=='分配课时'">-->
<!--          <el-input-->
<!--              placeholder="请输入已用课时"-->
<!--              v-model.trim="state.form.spendPeriod"-->
<!--              @input="state.form.spendPeriod= state.form.spendPeriod.replace(/[^0-9]/g,'')">-->
<!--            <template #append v-if="state.form.spendPeriod"><span>{{(state.form.spendPeriod /60).toFixed(2).replace(/\.00$/, '') + '分钟'}}</span></template>-->
<!--          </el-input>-->
<!--        </el-form-item>-->
        <el-form-item label="总课时:" prop="totalPeriod">
          <el-input
              :disabled="title === '编辑'"
              placeholder="请输入总课时"
              v-model.trim="state.form.totalPeriod"
              maxlength="10"
              @input="state.form.totalPeriod = state.form.totalPeriod.replace(/[^0-9]/g,'')">
            <template #append >分钟</template>
          </el-input>
        </el-form-item>
      </el-form>
      <template #footer>
        <span class="dialog-footer">
            <el-button @click="handleClose" size="default">取 消</el-button>
            <el-button type="primary"  @click="onSubmit" size="default" v-preReClick>确认</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>
<script setup>
import {reactive, ref, toRefs} from 'vue'
import Editor from "@/components/Editor/index.vue";
import {ElMessage} from "element-plus";
import {addNotice} from "@/api/backManage/notice";
import {addDict, editDict, getDictDetail} from "@/api/backManage/evaluate";
import {addCompany, checkName, distributeCompany, editCompany} from "@/api/onlineEducation/company";
import {verifyPhone} from "@/utils/validate";

const dialogVisible = ref(false);
const title = ref("");
const busRef = ref();
const length = ref()
const emit = defineEmits(["getList"]);
const startUsername = ref('');
const startPhone = ref('');

const validateName = (rule, value, callback)=>{
  if(value === ''){
    callback(new Error('请输入企业名称'))
  }else if(title.value === '编辑' && value === startUsername.value){
    callback()
  }else{
    let param = {}
    if(title.value === '新增') {
      param = {
        name:value
      }
    }else if(title.value === '编辑'){
      param = {
        name:value,
        id: state.form.id
      }
    }
    checkName(param).then((res)=>{
      if(res.data == false){
        callback(new Error('企业名称已被占用，请更换其他名称'))
      }else{
        callback()
      }
    })
  }
}
const validatePhone = (rule, value, callback)=>{
  if(value === ''){
    callback(new Error('请输入手机号'))
  }else if(title.value === '编辑' && value == startPhone.value){
    callback()
  } else{
    if(!verifyPhone(value)){
      callback(new Error('手机号格式有误'))
    }else {
      callback()
    }
  }
}
const state = reactive({
  form: {
    id: '',
    creditCode: '',
    name: '',
    major: '',
    phone: '',
    remainPeriod: '',
    spendPeriod: '',
    totalPeriod: ''
  },
  formRules:{
    creditCode: [{ required: true, message: '请输入企业信用代码', trigger: 'blur' }],
    major:[{ required: true, message: '请输入负责人', trigger: 'blur' }],
    remainPeriod:[{ required: true, message: '请输入剩余课时', trigger: 'blur' }],
    spendPeriod:[{ required: true, message: '请输入已用课时', trigger: 'blur' }],
    totalPeriod:[{ required: true, message: '请输入总课时', trigger: 'blur' }],
    name: [{ required: true, trigger: "blur", validator: validateName }],
    phone:[{ required: true, trigger: "blur", validator: validatePhone }],
  },
})


const openDialog = async (type, value) => {
  length.value = value.listLength
  title.value = type === 'add' ? '新增' : type ==='edit' ? '编辑' : '分配课时' ;
  if(type === 'edit' || type === 'distribute') {
    state.form = JSON.parse(JSON.stringify(value));
    state.form.totalPeriod = value.totalPeriod / 60;
    state.form.remainPeriod = value.remainPeriod/60;
    startUsername.value = value.username
    startPhone.value = value.phone
  }
  dialogVisible.value = true;
}

const onSubmit = async () => {
  const valid = await busRef.value.validate();
  if(valid){
    if(title.value === '新增'){
      const {id, ...data} = JSON.parse(JSON.stringify(state.form))
      data.totalPeriod = data.totalPeriod * 60
      data.remainPeriod = data.remainPeriod * 60
      const res = await addCompany(data)
      if(res.code === 200){
        ElMessage({
          type: 'success',
          message: '新增成功'
        });
      }else{
        ElMessage.warning(res.message)
      }
      emit("getList")
      busRef.value.clearValidate();
      reset();
      dialogVisible.value = false;
    }else if(title.value === '编辑'){
      const {...data} = JSON.parse(JSON.stringify(state.form))
      data.totalPeriod = data.totalPeriod * 60
      data.remainPeriod = data.remainPeriod * 60
      const res = await editCompany(data)
      if(res.code === 200){
        ElMessage({
          type: 'success',
          message: '编辑成功'
        });
      }else{
        ElMessage.warning(res.message)
      }
      emit("getList")
      busRef.value.clearValidate();
      reset();
      dialogVisible.value = false;
    }else if(title.value === '分配课时') {
      const {creditCode,name,major,phone,remainPeriod,spendPeriod,...data} = JSON.parse(JSON.stringify(state.form))
      data.totalPeriod = data.totalPeriod * 60
      const res = await distributeCompany(data)
      if(res.code === 200){
        ElMessage({
          type: 'success',
          message: '成功'
        });
      }else{
        ElMessage.warning(res.message)
      }
      emit("getList")
      busRef.value.clearValidate();
      reset();
      dialogVisible.value = false;
    }
  }
}

const handleClose = () => {
  busRef.value.clearValidate();
  reset();
  dialogVisible.value = false;
  emit("getList")

}
const reset = () => {
  state.form = {
    id: '',
    creditCode: '',
    name: '',
    major: '',
    phone: '',
    remainPeriod: '',
    spendPeriod: '',
    totalPeriod: ''
  }
}
defineExpose({
  openDialog
});

</script>

<style scoped lang="scss">
.notice{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
  .file {
    display: flex;
    flex-direction: column;
    align-items: flex-start;
  }
}
</style>
